@@ -47,7 +47,7 @@ option:
                     edata = nan
             if skipnan:
                 tdatacosel = array(tdatacosel)
-                tdatacosel = tdatacosel[where(isnan(tdatacsel == False))]
+                tdatacosel = tdatacosel[where(isnan(tdatacosel) == False))]
             dataout.append(mean(tdatacosel))
             timecoout.append(timeco[idata])
             #dataout.append(mean(scisel(data,timeco,tempco2) )
